==> servicecatalog-model-6.2.0-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBrokerStatusFluent.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ServiceBrokerStatusFluent<A extends ServiceBrokerStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,ServiceBrokerCondition item);
  public A setToConditions(Integer index,ServiceBrokerCondition item);
  public A addToConditions(io.fabric8.servicecatalog.api.model.ServiceBrokerCondition... items);
  public A addAllToConditions(Collection<ServiceBrokerCondition> items);
  public A removeFromConditions(io.fabric8.servicecatalog.api.model.ServiceBrokerCondition... items);
  public A removeAllFromConditions(Collection<ServiceBrokerCondition> items);
  public A removeMatchingFromConditions(Predicate<ServiceBrokerConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServiceBrokerCondition> getConditions();
  public List<ServiceBrokerCondition> buildConditions();
  public ServiceBrokerCondition buildCondition(Integer index);
  public ServiceBrokerCondition buildFirstCondition();
  public ServiceBrokerCondition buildLastCondition();
  public ServiceBrokerCondition buildMatchingCondition(Predicate<ServiceBrokerConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ServiceBrokerConditionBuilder> predicate);
  public A withConditions(List<ServiceBrokerCondition> conditions);
  public A withConditions(io.fabric8.servicecatalog.api.model.ServiceBrokerCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public ServiceBrokerStatusFluent.ConditionsNested<A> addNewCondition();
  public ServiceBrokerStatusFluent.ConditionsNested<A> addNewConditionLike(ServiceBrokerCondition item);
  public ServiceBrokerStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,ServiceBrokerCondition item);
  public ServiceBrokerStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public ServiceBrokerStatusFluent.ConditionsNested<A> editFirstCondition();
  public ServiceBrokerStatusFluent.ConditionsNested<A> editLastCondition();
  public ServiceBrokerStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ServiceBrokerConditionBuilder> predicate);
  public String getLastCatalogRetrievalTime();
  public A withLastCatalogRetrievalTime(String lastCatalogRetrievalTime);
  public Boolean hasLastCatalogRetrievalTime();
  public String getOperationStartTime();
  public A withOperationStartTime(String operationStartTime);
  public Boolean hasOperationStartTime();
  public Long getReconciledGeneration();
  public A withReconciledGeneration(Long reconciledGeneration);
  public Boolean hasReconciledGeneration();
  public interface ConditionsNested<N> extends Nested<N>,ServiceBrokerConditionFluent<ServiceBrokerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceBrokerStatusFluent.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ServiceBrokerStatusFluent<A extends ServiceBrokerStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,ServiceBrokerCondition item);
  public A setToConditions(int index,ServiceBrokerCondition item);
  public A addToConditions(io.fabric8.servicecatalog.api.model.ServiceBrokerCondition... items);
  public A addAllToConditions(Collection<ServiceBrokerCondition> items);
  public A removeFromConditions(io.fabric8.servicecatalog.api.model.ServiceBrokerCondition... items);
  public A removeAllFromConditions(Collection<ServiceBrokerCondition> items);
  public A removeMatchingFromConditions(Predicate<ServiceBrokerConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ServiceBrokerCondition> getConditions();
  public List<ServiceBrokerCondition> buildConditions();
  public ServiceBrokerCondition buildCondition(int index);
  public ServiceBrokerCondition buildFirstCondition();
  public ServiceBrokerCondition buildLastCondition();
  public ServiceBrokerCondition buildMatchingCondition(Predicate<ServiceBrokerConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ServiceBrokerConditionBuilder> predicate);
  public A withConditions(List<ServiceBrokerCondition> conditions);
  public A withConditions(io.fabric8.servicecatalog.api.model.ServiceBrokerCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public ServiceBrokerStatusFluent.ConditionsNested<A> addNewCondition();
  public ServiceBrokerStatusFluent.ConditionsNested<A> addNewConditionLike(ServiceBrokerCondition item);
  public ServiceBrokerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,ServiceBrokerCondition item);
  public ServiceBrokerStatusFluent.ConditionsNested<A> editCondition(int index);
  public ServiceBrokerStatusFluent.ConditionsNested<A> editFirstCondition();
  public ServiceBrokerStatusFluent.ConditionsNested<A> editLastCondition();
  public ServiceBrokerStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ServiceBrokerConditionBuilder> predicate);
  public String getLastCatalogRetrievalTime();
  public A withLastCatalogRetrievalTime(String lastCatalogRetrievalTime);
  public Boolean hasLastCatalogRetrievalTime();
  public String getOperationStartTime();
  public A withOperationStartTime(String operationStartTime);
  public Boolean hasOperationStartTime();
  public Long getReconciledGeneration();
  public A withReconciledGeneration(Long reconciledGeneration);
  public Boolean hasReconciledGeneration();
  public interface ConditionsNested<N> extends Nested<N>,ServiceBrokerConditionFluent<ServiceBrokerStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
